import { type OptionValues as CliOptionValues } from "commander";
import { AdderDetails, AddersExecutionPlan } from "./execute.js";
import { type PromptOption } from "../utils/prompts.js";
export type BooleanQuestion = {
    type: "boolean";
    default: boolean;
};
export type StringQuestion = {
    type: "string";
    default: string;
};
export type NumberQuestion = {
    type: "number";
    default: number;
};
export type SelectQuestion<Value = any> = {
    type: "select";
    default: Value;
    options: PromptOption<Value>[];
};
export type BaseQuestion = {
    question: string;
    condition?: (options: OptionValues<any>) => boolean;
};
export type Question = BaseQuestion & (BooleanQuestion | StringQuestion | NumberQuestion | SelectQuestion);
export type OptionDefinition = Record<string, Question>;
export type OptionValues<Args extends OptionDefinition> = {
    [K in keyof Args]: Args[K] extends StringQuestion ? string : Args[K] extends BooleanQuestion ? boolean : Args[K] extends NumberQuestion ? number : Args[K] extends SelectQuestion<infer Value> ? Value : never;
};
export type AvailableCliOptionKeys = keyof AvailableCliOptionKeyTypes;
export type AvailableCliOptionKeyTypes = {
    default: boolean;
    path: string;
    skipPreconditions: boolean;
    skipInstall: boolean;
};
export type AvailableCliOptionValues = {
    [K in AvailableCliOptionKeys]?: AvailableCliOptionKeyTypes[K];
} & {
    adders?: string[];
};
export type AvailableCliOption = {
    cliArg: string;
    processedCliArg: string;
    description: string;
    allowShorthand: boolean;
} & (BooleanQuestion | StringQuestion);
export type AvailableCliOptions = Record<AvailableCliOptionKeys, AvailableCliOption>;
export declare const availableCliOptions: AvailableCliOptions;
export declare function prepareAndParseCliOptions<Args extends OptionDefinition>(adderDetails: AdderDetails<Args>[]): CliOptionValues;
export declare function ensureCorrectOptionTypes<Args extends OptionDefinition>(adderDetails: AdderDetails<Args>[], cliOptionsByAdderId: Record<string, Record<string, any>>): void;
export declare function extractCommonCliOptions(cliOptions: CliOptionValues): AvailableCliOptionValues;
export declare function extractAdderCliOptions<Args extends OptionDefinition>(cliOptions: CliOptionValues, adderDetails: AdderDetails<Args>[]): Record<string, Record<string, any>>;
export declare function requestMissingOptionsFromUser<Args extends OptionDefinition>(adderDetails: AdderDetails<Args>[], executionPlan: AddersExecutionPlan): Promise<void>;
