import { CssAstEditor, HtmlAstEditor, JsAstEditor, SvelteAstEditor } from "@svelte-add/ast-manipulation";
import { ConditionDefinition } from "../adder/config.js";
import { OptionDefinition } from "../adder/options.js";
import { Workspace } from "../utils/workspace.js";
export type BaseFile<Args extends OptionDefinition> = {
    name: (options: Workspace<Args>) => string;
    condition?: ConditionDefinition<Args>;
};
export type ScriptFileEditorArgs<Args extends OptionDefinition> = JsAstEditor & Workspace<Args>;
export type ScriptFileType<Args extends OptionDefinition> = {
    contentType: "script";
    content: (editor: ScriptFileEditorArgs<Args>) => void;
};
export type ScriptFile<Args extends OptionDefinition> = ScriptFileType<Args> & BaseFile<Args>;
export type TextFileEditorArgs<Args extends OptionDefinition> = {
    content: string;
} & Workspace<Args>;
export type TextFileType<Args extends OptionDefinition> = {
    contentType: "text";
    content: (editor: TextFileEditorArgs<Args>) => string;
};
export type TextFile<Args extends OptionDefinition> = TextFileType<Args> & BaseFile<Args>;
export type SvelteFileEditorArgs<Args extends OptionDefinition> = SvelteAstEditor & Workspace<Args>;
export type SvelteFileType<Args extends OptionDefinition> = {
    contentType: "svelte";
    content: (editor: SvelteFileEditorArgs<Args>) => void;
};
export type SvelteFile<Args extends OptionDefinition> = SvelteFileType<Args> & BaseFile<Args>;
export type JsonFileEditorArgs<Args extends OptionDefinition> = {
    data: any;
} & Workspace<Args>;
export type JsonFileType<Args extends OptionDefinition> = {
    contentType: "json";
    content: (editor: JsonFileEditorArgs<Args>) => void;
};
export type JsonFile<Args extends OptionDefinition> = JsonFileType<Args> & BaseFile<Args>;
export type HtmlFileEditorArgs<Args extends OptionDefinition> = HtmlAstEditor & Workspace<Args>;
export type HtmlFileType<Args extends OptionDefinition> = {
    contentType: "html";
    content: (editor: HtmlFileEditorArgs<Args>) => void;
};
export type HtmlFile<Args extends OptionDefinition> = HtmlFileType<Args> & BaseFile<Args>;
export type CssFileEditorArgs<Args extends OptionDefinition> = CssAstEditor & Workspace<Args>;
export type CssFileType<Args extends OptionDefinition> = {
    contentType: "css";
    content: (editor: CssFileEditorArgs<Args>) => void;
};
export type CssFile<Args extends OptionDefinition> = CssFileType<Args> & BaseFile<Args>;
export type FileTypes<Args extends OptionDefinition> = ScriptFile<Args> | TextFile<Args> | SvelteFile<Args> | JsonFile<Args> | HtmlFile<Args> | CssFile<Args>;
export declare function createOrUpdateFiles<Args extends OptionDefinition>(files: FileTypes<Args>[], workspace: Workspace<Args>): Promise<void>;
